pro h5info, file, nattrs = nattrs, nvars = nvars, dims = dm, pdims = pm $
          , nguard = ng, nchunks = nchks, step = step, time = time      $
	  , dt = dt, newdt = dtn, pcoords = pc, bext = bext, nfor = nf  $
	  , efor = ef, cfor = cf, vfor = vf, sfor = sf, nseeds = nsds   $
	  , seed = seed, names = names, attrs = attrs, nrun = nrun      $
	  , cfl = cfl, csnd = csnd, fordt = dtfor, inidt = dtini        $
	  , mindt = dtmin, dx = dx, dy = dy, dz = dz, gamma = gamma     $
	  , kf = kf, kl = kl, ku = ku, kc = kc, pwfor = pwfor           $
	  , xmin = xmin, xmax = xmax, ymin = ymin, ymax = ymax          $
	  , zmin = zmin, zmax = zmax, print = p

; initiate info attributes
;
  nattrs = 0l
  nvars  = 0l
  ng     = 0l
  nchks  = 1l
  dm     = [ 1l, 1l, 1l ]
  pm     = [ 1l, 1l, 1l ]
  pc     = [ 0l, 0l, 0l ]
  step   = 0l
  time   = 0.0
  dt     = 1.0
  dtn    = 1.0
  bext   = [ 0.0, 0.0, 0.0 ]
  nf     = 0l
  ef     = 0.0
  cf     = 0.0
  vf     = 0.0
  sf     = 0.0
  nrun   = 1
  nsds   = 0l
  seed   = 0.0
  cfl    = 1.0
  csnd   = 1.0
  dtfor  = 1.0
  dtini  = 1.0
  dtmin  = 0.0
  dx     = 1.0
  dy     = 1.0
  dz     = 1.0
  dxi    = 1.0
  dyi    = 1.0
  dzi    = 1.0
  gamma  = 1.0
  kf     = 0.0
  kl     = 0.0
  ku     = 0.0
  kc     = 0.0
  xmin   = 0.0
  xmax   = 1.0
  ymin   = 0.0
  ymax   = 1.0
  zmin   = 0.0
  zmax   = 1.0

; open the file
;
  fid = h5f_open(file)

; check if there were problems with opening the SD interface
;
  if (fid le 0) then begin

; close a file
;
    h5f_close, fid

; print a message and terminate
;
    message, 'Could not open the file ' + file + '!'

  endif

; open group 'attributes'
;
  gid = h5g_open(fid, 'attributes')

; get number of attributes
;
  nattrs = h5a_get_num_attrs(gid)

; print all attribute names
;
  if (keyword_set(p)) then print, 'Number of attributes:', nattrs
  attrs = strarr(nattrs)
  if (keyword_set(p)) then print, 'Attribute names:'
  for n = 0, nattrs - 1 do begin
    aid  = h5a_open_idx(gid, n)
    nm   = h5a_get_name(aid)
    data = h5a_read(aid)
    case nm of
      'step'    : step  = data[0]
      'time'    : time  = data[0]
      'dt'      : dt    = data[0]
      'dtn'     : dtn   = data[0]
      'dims'    : dm    = data
      'pdims'   : pm    = data
      'ng'      : ng    = data[0]
      'bext'    : bext  = data
      'nf'      : nf    = data[0]
      'efor'    : ef    = data[0]
      'cfor'    : cf    = data[0]
      'vfor'    : vf    = data[0]
      'sfor'    : sf    = data[0]
      'nseeds'  : nsds  = data[0]
      'seed'    : seed  = data
      'nprocs'  : nchks = data[0]
      'pcoords' : pc    = data
      'nrun'    : nrun  = data[0]
      'cfl'     : cfl   = data[0]
      'csnd'    : csnd  = data[0]
      'dtfor'   : dtfor = data[0]
      'dtini'   : dtini = data[0]
      'dtmin'   : dtmin = data[0]
      'dx'      : dx    = data[0]
      'dy'      : dy    = data[0]
      'dz'      : dz    = data[0]
      'dxi'     : dxi   = data[0]
      'dyi'     : dyi   = data[0]
      'dzi'     : dzi   = data[0]
      'gamma'   : gamma = data[0]
      'pwfor'   : pwfor = data[0]
      'kf'      : kf    = data[0]
      'kl'      : kl    = data[0]
      'ku'      : ku    = data[0]
      'kc'      : kc    = data[0]
      'xmin'    : xmin  = data[0]
      'xmax'    : xmax  = data[0]
      'ymin'    : ymin  = data[0]
      'ymax'    : ymax  = data[0]
      'zmin'    : zmin  = data[0]
      'zmax'    : zmax  = data[0]
    else :
    endcase
    h5a_close, aid
    attrs[n] = nm
  endfor
  if (keyword_set(p)) then print, '    ', attrs
  if (keyword_set(p)) then print, ''

; close group 'attributes'
;
  h5g_close, gid

; open group 'variables'
;
    gid = h5g_open(fid, 'variables')

; get number of datasets
;
    nvars = h5g_get_num_objs(gid)

; print all dataset names
;
    if (keyword_set(p)) then print, 'Number of datasets  :', nvars
    names = strarr(nvars)
    if (keyword_set(p)) then print, 'Dataset names:'
    for n = 0, nvars - 1 do begin
      nm = h5g_get_obj_name_by_idx(gid, n)
      names[n] = nm
    endfor
    if (keyword_set(p)) then print, '    ', names
    if (keyword_set(p)) then print, ''

; close group 'variables'
;
    h5g_close, gid

; close the file
;
  h5f_close, fid

end
